@@ -732,51 +732,51 @@ class Thalassa:
 						value = int(value)
 					else:
 						value = string_to_timestamp(value)
-					if 'newer than' not in filters or filters['newer than'] < value:
+					if 'newer than' not in filters.keys() or filters['newer than'] < value:
 						filters['newer than'] = value
 				elif 'older than:' == tag[:11]:
 					value = tag[11:]
 					if re.match('^[0-9]*$', value):
 						value = int(value)
 					else:
-						string_to_timestamp(value)
-					if 'older than' not in filters or filters['older than'] > value:
+						value = string_to_timestamp(value)
+					if 'older than' not in filters.keys() or filters['older than'] > value:
 						filters['older than'] = value
 				# file size
 				elif 'smaller than:' == tag[:13]:
 					value = int(tag[13:])
-					if 'smaller than' not in filters or filters['smaller than'] > value:
+					if 'smaller than' not in filters.keys() or filters['smaller than'] > value:
 						filters['smaller than'] = value
 				elif 'larger than:' == tag[:12]:
 					value = tag[12:]
-					if 'larger than' not in filters or filters['larger than'] < value:
+					if 'larger than' not in filters.keys() or filters['larger than'] < value:
 						filters['larger than'] = value
 				# width
 				elif 'wider than:' == tag[:11]:
 					value = int(tag[11:])
-					if 'wider than' not in filters or filters['wider than'] < value:
+					if 'wider than' not in filters.keys() or filters['wider than'] < value:
 						filters['wider than'] = value
 				elif 'narrower than:' == tag[:14]:
 					value = int(tag[14:])
-					if 'narrower than' not in filters or filters['narrower than'] > value:
+					if 'narrower than' not in filters.keys() or filters['narrower than'] > value:
 						filters['narrower than'] = value
 				# height
 				elif 'taller than:' == tag[:12]:
 					value = int(tag[12:])
-					if 'taller than' not in filters or filters['taller than'] < value:
+					if 'taller than' not in filters.keys() or filters['taller than'] < value:
 						filters['taller than'] = value
 				elif 'shorter than:' == tag[:13]:
 					value = int(tag[13:])
-					if 'shorter than' not in filters or filters['shorter than'] > value:
+					if 'shorter than' not in filters.keys() or filters['shorter than'] > value:
 						filters['shorter than'] = value
 				# duration
 				elif 'duration shorter than:' == tag[:22]:
 					value = int(tag[22:])
-					if 'duration shorter than' not in filters or filters['duration shorter than'] > value:
+					if 'duration shorter than' not in filters.keys() or filters['duration shorter than'] > value:
 						filters['duration shorter than'] = value
 				elif 'duration longer than:' == tag[:21]:
 					value = int(tag[21:])
-					if 'duration longer than' not in filters or filters['duration longer than'] < value:
+					if 'duration longer than' not in filters.keys() or filters['duration longer than'] < value:
 						filters['duration longer than'] = value
 				# orientation
 				elif 'orientation:' == tag[:12]:
@@ -1375,52 +1375,52 @@ class Thalassa:
 				# filters
 				if filters:
 					# publish time
-					if 'newer than' in filters:
+					if 'newer than' in filters.keys():
 						sql += ' AND publish_time > ?'
 						values.append(filters['newer than'])
-					if 'older than' in filters:
+					if 'older than' in filters.keys():
 						sql += ' AND publish_time < ?'
 						values.append(filters['older than'])
 					# file size
-					if 'smaller than' in filters:
+					if 'smaller than' in filters.keys():
 						sql += ' AND size < ?'
 						values.append(filters['smaller than'])
-					if 'larger than' in filters:
+					if 'larger than' in filters.keys():
 						sql += ' AND size > ?'
 						values.append(filters['larger than'])
 					# width
-					if 'wider than' in filters:
+					if 'wider than' in filters.keys():
 						sql += ' AND width > ?'
 						values.append(filters['wider than'])
-					if 'narrower than' in filters:
+					if 'narrower than' in filters.keys():
 						sql += ' AND width < ?'
 						values.append(filters['narrower than'])
 					# height
-					if 'taller than' in filters:
+					if 'taller than' in filters.keys():
 						sql += ' AND height > ?'
 						values.append(filters['taller than'])
-					if 'shorter than' in filters:
+					if 'shorter than' in filters.keys():
 						sql += ' AND height < ?'
 						values.append(filters['shorter than'])
 					# duration
-					if 'duration shorter than' in filters:
+					if 'duration shorter than' in filters.keys():
 						sql += ' AND duration < ?'
 						values.append(filters['duration shorter than'])
-					if 'duration longer than' in filters:
+					if 'duration longer than' in filters.keys():
 						sql += ' AND duration > ?'
 						values.append(filters['duration longer than'])
 					# orientation
-					if 'orientation' in filters:
+					if 'orientation' in filters.keys():
 						if 'portrait' == filters['orientation']:
 							sql += ' AND width < height'
 						elif 'landscape' == filters['orientation']:
 							sql += ' AND height < width'
 					# mimetype
-					if 'mimetype' in filters:
+					if 'mimetype' in filters.keys():
 						sql += ' AND mimetype = ?'
 						values.append(filters['mimetype'])
 					# category
-					if 'category' in filters:
+					if 'category' in filters.keys():
 						if filters['category'] in self.category_mimes:
 							sql += ' AND ('
 							mimetype_sql = ''
@@ -1431,18 +1431,18 @@ class Thalassa:
 								mimetype_sql = mimetype_sql[:-3]
 							sql += mimetype_sql + ')'
 					# owner
-					if 'owner' in filters:
+					if 'owner' in filters.keys():
 						sql += ' AND owner = ?'
 						values.append(filters['owner'])
 					# order by, sort, and pagination
-					if 'order by' in filters:
+					if 'order by' in filters.keys():
 						if filters['order by'] in ['upload', 'publish', 'size', 'height', 'width', 'duration']:
 							if filters['order by'] in ['upload', 'publish']:
 								filters['order by'] += '_time'
 							order_by = filters['order by']
-					if 'sort' in filters:
+					if 'sort' in filters.keys():
 						sort = filters['sort']
-					if 'perpage' in filters:
+					if 'perpage' in filters.keys():
 						perpage = int(filters['perpage'])
 
 				# tags
